# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import gtk.glade
import consts

# Base class for all dialogs
class DlgBase :

    # Constructor
    def __init__(self, parent, dlgName, widgets=[]) :
        # This is needed when custom widgets are used
        gtk.glade.set_custom_handler(self.getCustomHandler)
        # Create the dialog
        self.wTree  = gtk.glade.XML(consts.dirRes + dlgName + '.glade')
        self.dialog = self.wTree.get_widget(dlgName)

        # Handle the response signal
        self.dialog.connect('response', self.onResponse)

        # Load all widgets
        for w in widgets :
            self.__dict__[w] = self.wTree.get_widget(w)

        # Tell the run() method which class is the parent of this dialog
        self.dialog.set_transient_for(parent)

    # Default behavior is to hide the dialog
    def onResponse(self, dialog, response, *args) :
        self.dialog.hide()

    # This function must be overriden when custom widgets are used
    def getCustomHandler(self, glade, function_name, widget_name, str1, str2, int1, int2) :
        pass

    # Show the dialog box
    def show(self) :
        return self.dialog.run()
