# -*- coding: utf-8 -*-
#
# Author: Ingelrest François (Athropos@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

from dlgBase import DlgBase
from prefsManager import prefs

import os
import gtk
import vte

class DlgOutput(DlgBase) :

    # Constructor
    def __init__(self, parent) :
        DlgBase.__init__(self, parent, 'dlg-output', ['txtOutput', 'btnClose', 'btnStop', 'vteOutput'])

        # Connect events
        self.wTree.signal_autoconnect(self)

        # Prepare the terminal
        self.vteOutput.show_all()
        self.vteOutput.connect("child-exited", self.onChildExited)

        # Restore previous size
        self.dialog.resize(prefs.outputDlgWidth, prefs.outputDlgHeight)        

    # The subprocess has exited
    def onChildExited(self, terminal) :
        self.btnClose.set_sensitive(True)
        self.btnStop.set_sensitive(False)

    # Creation of custom widgets
    def getCustomHandler(self, glade, function_name, widget_name, str1, str2, int1, int2) :
        if function_name == 'createVTE' :
            return vte.Terminal()

    # Stop button was clicked
    def onBtnStop(self, widget) :
        global cmdPid
        os.kill(cmdPid, 9)

    # Save the current size
    def onDlgResize(self, window, rectangle) :
        prefs.outputDlgWidth  = rectangle.width
        prefs.outputDlgHeight = rectangle.height

    # Only allow CLOSE signal
    def onResponse(self, dialog, response, *args) :
        if response == gtk.RESPONSE_CLOSE :
            DlgBase.onResponse(self, dialog, response, args)
        else :
            self.dialog.stop_emission('response')

    # Display the dialog box and execute the given command line
    def show(self, cmd, args) :
        global cmdPid
        self.btnClose.set_sensitive(False)
        self.btnStop.set_sensitive(True)
        self.dialog.show()
        # Execute the command
        cmdPid = self.vteOutput.fork_command(cmd, args)

# === This object is a singleton
dlg = None
def instance(parent) :
    global dlg
    if dlg is None :
        dlg = DlgOutput(parent)
    return dlg
